@@ -41,6 +41,7 @@ def sync_algorithm(
     uploader: Optional[ResourceUploader]=None,
     polling: Union[float, int]=5,
     force: bool=False,
+    commit_msg: str=None,
 ) -> Tuple[Algorithm, str]:
     if id:
         return _sync_remote_algorithm(
@@ -59,6 +60,7 @@ def sync_algorithm(
             uploader=uploader,
             polling=polling,
             force=force,
+            commit_msg=commit_msg,
         )
 
 
@@ -87,7 +89,8 @@ def _sync_local_algorithm(
     image_name: str="QUICKSTART",
     uploader: Optional[ResourceUploader]=None,
     polling: Union[float, int]=5,
-    force: bool=False
+    force: bool=False,
+    commit_msg: str=None,
 ) -> Tuple[Algorithm, Optional[str]]:
     # Required params
     if not all([dir_path, entrypoint_training, output_training]):
@@ -111,6 +114,7 @@ def _sync_local_algorithm(
             algorithm=algo,
             dir_path=dir_path,
             force=force,
+            commit_msg=commit_msg,
         )
         logger.info("Waiting algorithm to be ready...")
         algo.sync_finish(checkout_sha=current_sha)
@@ -199,9 +203,12 @@ def _get_quickstart_mirror(name: str) -> Mirror:
             "the connected backend."
         ))
 
-def _sync_algorithm_repo(algorithm: Algorithm,
-                         dir_path: str,
-                         force: bool=False) -> None:
+def _sync_algorithm_repo(
+    algorithm: Algorithm,
+    dir_path: str,
+    force: bool=False,
+    commit_msg: str=None,
+) -> None:
     if AnylearnConfig.git_ready:
         from git import Repo
         from .git_progress_printer import GitProgressPrinter
@@ -238,7 +245,9 @@ def _sync_algorithm_repo(algorithm: Algorithm,
             f"Forced auto-committing changes in '{dir_path}'"
         )
         logger.debug("Commiting")
-        repo.index.commit(_commit_msg())
+        if not commit_msg:
+            commit_msg = _commit_msg()
+        repo.index.commit(commit_msg)
     push_args = {'all': True}
     if force:
         push_args['force'] = True
