@@ -9,7 +9,7 @@ from typing import Optional, Union
 from .utils import (
     _get_archive_checksum,
     _get_or_create_resource_archive,
-    generate_random_name,
+    make_name_by_path,
 )
 from ..interfaces.resource import (
     Dataset,
@@ -64,7 +64,7 @@ def _sync_local_dataset(
             "is specified."
         ))
     if not name:
-        name = f"DSET_{generate_random_name()}"
+        name = make_name_by_path(dir_path or archive_path)
     archive_path = _get_or_create_resource_archive(
         name=name,
         dir_path=dir_path,
